@@ -19,7 +19,6 @@
 
 /* begin                : Wed Jul 18 2001 */
 
-#define KDE_NO_COMPAT
 #include "country.h"
 #include "player.h"
 #include "Sprites/backgnd.h"
@@ -606,5 +605,3 @@ void Country::copyForArena(Country* trueCountry)
 } // closing namespace GameLogic
 
 } // closing namespace Ksirk
-
-#include "moc_country.cpp"
