@@ -124,7 +124,7 @@ MainWindow::MainWindow(QWidget* parent) :
   QString anchorFileName = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("cross.png"));
   if (anchorFileName.isNull())
   {
-    KMessageBox::error(nullptr, i18n("Cannot load anchor icon<br>Program cannot continue"), i18n("Error"));
+    KMessageBox::error(nullptr, i18n("Cannot load anchor icon<br>Program cannot continue"));
     exit(2);
   }
   QPixmap anchorPix = QPixmap(anchorFileName);
@@ -138,7 +138,7 @@ MainWindow::MainWindow(QWidget* parent) :
   QString centerFileName = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("target.png"));
   if (centerFileName.isNull())
   {
-    KMessageBox::error(nullptr, i18n("Cannot load center icon<br>Program cannot continue"), i18n("Error"));
+    KMessageBox::error(nullptr, i18n("Cannot load center icon<br>Program cannot continue"));
     exit(2);
   }
   QPixmap centerPix = QPixmap(centerFileName);
@@ -155,7 +155,7 @@ MainWindow::MainWindow(QWidget* parent) :
   QString iconFileName = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("ksirkskineditor.png"));
 /*  if (iconFileName.isNull())
   {
-      KMessageBox::error(0, i18n("Cannot load icon<br>Program cannot continue"), i18n("Error"));
+      KMessageBox::error(0, i18n("Cannot load icon<br>Program cannot continue"));
       exit(2);
   }*/
   QPixmap icon(iconFileName);
@@ -192,7 +192,7 @@ MainWindow::MainWindow(QWidget* parent) :
   connect (m_goalDefWidget->description,&QTextEdit::textChanged, this, &MainWindow::slotGoalDescriptionEdited);
   connect (m_goalDefWidget->nbcountries, &QSpinBox::valueChanged, this, &MainWindow::slotGoalNbCountriesChanged);
   connect (m_goalDefWidget->armiesbycountry, &QSpinBox::valueChanged, this, &MainWindow::slotGoalNbArmiesByCountryChanged);
-  connect (m_goalDefWidget->anycontinent,&QCheckBox::stateChanged, this, &MainWindow::slotGoalAnyContinentChanged);
+  connect (m_goalDefWidget->anycontinent,&QCheckBox::toggled, this, &MainWindow::slotGoalAnyContinentChanged);
   connect (m_goalDefWidget->selectcontinentsbutton, &QAbstractButton::clicked, this, &MainWindow::slotGoalContinents);
   connect(m_skinDefWidget->newGoalButton, &QAbstractButton::clicked, this, &MainWindow::slotNewGoal);
   connect(m_skinDefWidget->deleteGoalButton, &QAbstractButton::clicked, this, &MainWindow::slotDeleteGoal);
@@ -321,12 +321,12 @@ void MainWindow::initActions()
   // standard game actions
   action = KGameStandardAction::load(this, &MainWindow::slotOpenSkin, this);
   actionCollection()->addAction(action->objectName(), action);
-  action->setToolTip(i18n("Open a saved skin..."));
+  action->setToolTip(i18nc("@info:tooltip", "Open a saved skin"));
 
   m_rfa = KGameStandardAction::loadRecent (this, &MainWindow::slotURLSelected, this);
   actionCollection()->addAction(m_rfa->objectName(), m_rfa);
-  m_rfa->setText(i18n("Load &Recent"));
-  m_rfa->setToolTip(i18n("Open a recently saved skin..."));
+  m_rfa->setText(i18nc("@action", "Load &Recent"));
+  m_rfa->setToolTip(i18nc("@info:tooltip", "Open a recently saved skin"));
 
   KSharedConfig::Ptr config = KSharedConfig::openConfig();
   qCDebug(KSIRKSKINEDITOR_LOG) << "loading recent files";
@@ -334,7 +334,7 @@ void MainWindow::initActions()
   
   m_saveGameAction = KGameStandardAction::save(this, &MainWindow::slotSaveSkin, this);
   actionCollection()->addAction(m_saveGameAction->objectName(), m_saveGameAction);
-  m_saveGameAction->setToolTip(i18n("Save the current skin"));
+  m_saveGameAction->setToolTip(i18nc("@info:tooltip", "Save the current skin"));
 
   action = KGameStandardAction::quit(this, &MainWindow::close, this);
   actionCollection()->addAction(action->objectName(), action);
@@ -524,10 +524,10 @@ bool MainWindow::queryClose()
   {
     switch (KMessageBox::warningTwoActionsCancel(this,
                                              i18n("There are unsaved changes. What do you want to do?"),
-                                             i18n("Exit Anyway?"),
-                                             KGuiItem(i18n("Quit without saving")),
-                                             KGuiItem(i18n("Save then quit")),
-                                             KGuiItem(i18n("Do not quit"))))
+                                             i18nc("@title:window", "Unsaved Changes"),
+                                             KGuiItem(i18nc("@action:button", "Quit Without Saving"), QStringLiteral("application-exit")),
+                                             KGuiItem(i18nc("@action:button", "Save and Quit"), QStringLiteral("document-save")),
+                                             KStandardGuiItem::cancel()))
     {
       case KMessageBox::PrimaryAction:
         return true;
@@ -675,7 +675,7 @@ void MainWindow::slotAnchorButtonClicked()
     QString anchorFileName = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("cross.png"));
     if (anchorFileName.isNull())
     {
-      KMessageBox::error(nullptr, i18n("Cannot load anchor icon<br>Program cannot continue"), i18n("Error"));
+      KMessageBox::error(nullptr, i18n("Cannot load anchor icon<br>Program cannot continue"));
       exit(2);
     }
     QPixmap anchorPix = QPixmap(anchorFileName);
@@ -704,7 +704,7 @@ void MainWindow::slotCenterButtonClicked()
     QString centerFileName = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("target.png"));
     if (centerFileName.isNull())
     {
-      KMessageBox::error(nullptr, i18n("Cannot load center icon<br>Program cannot continue"), i18n("Error"));
+      KMessageBox::error(nullptr, i18n("Cannot load center icon<br>Program cannot continue"));
       exit(2);
     }
     QPixmap centerPix = QPixmap(centerFileName);
@@ -717,7 +717,7 @@ void MainWindow::slotCenterButtonClicked()
 
 void MainWindow::slotPosition(const QPointF& point)
 {
-  QString message(QLatin1String(""));
+  QString message;
   QTextStream ts( &message );
   ts << point.x() << " x " << point.y();
   statusBar()->showMessage(message);
@@ -803,7 +803,7 @@ void MainWindow::slotPressPosition(const QPointF& clickedPoint)
       fileName = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("cross.png"));
       if (fileName.isNull())
       {
-        KMessageBox::error(nullptr, i18n("Cannot load anchor icon<br>Program cannot continue"), i18n("Error"));
+        KMessageBox::error(nullptr, i18n("Cannot load anchor icon<br>Program cannot continue"));
         exit(2);
       }
       pix = QPixmap(fileName);
@@ -820,7 +820,7 @@ void MainWindow::slotPressPosition(const QPointF& clickedPoint)
       fileName = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("target.png"));
       if (fileName.isNull())
       {
-        KMessageBox::error(nullptr, i18n("Cannot load center icon<br>Program cannot continue"), i18n("Error"));
+        KMessageBox::error(nullptr, i18n("Cannot load center icon<br>Program cannot continue"));
         exit(2);
       }
       pix = QPixmap(fileName);
@@ -1190,7 +1190,7 @@ void MainWindow::createPixmapFor(Country* country, SpriteType type)
       fileName = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("cross.png"));
       if (fileName.isNull())
       {
-        KMessageBox::error(nullptr, i18n("Cannot load anchor icon<br>Program cannot continue"), i18n("Error"));
+        KMessageBox::error(nullptr, i18n("Cannot load anchor icon<br>Program cannot continue"));
         exit(2);
       }
       pix = QPixmap(fileName);
@@ -1302,7 +1302,7 @@ void MainWindow::slotNewCountry()
 {
   if (m_onu == nullptr) return;
   qCDebug(KSIRKSKINEDITOR_LOG);
-  QString newCountryName = QInputDialog::getText(this, i18n("New country name"), i18n("Enter the name of the new country"));
+  QString newCountryName = QInputDialog::getText(this, i18nc("@title:window", "New Country Name"), i18nc("@label:textbox", "Enter the name of the new country:"));
   m_onu->createCountry(newCountryName);
   m_skinDefWidget->countrieslist->addItem(newCountryName);
 }
@@ -1312,7 +1312,7 @@ void MainWindow::slotDeleteCountry()
   if (m_onu == nullptr) return;
   if (!m_skinDefWidget->countrieslist->currentItem()) return;
   qCDebug(KSIRKSKINEDITOR_LOG);
-  int answer = KMessageBox::warningContinueCancel(this, i18n("Do you really want to delete country '%1'?", m_skinDefWidget->countrieslist->currentItem()->text()), i18n("Really delete country?"));
+  int answer = KMessageBox::warningContinueCancel(this, i18n("Do you really want to delete country '%1'?", m_skinDefWidget->countrieslist->currentItem()->text()), i18nc("@title:window", "Delete Country Confirmation"));
   if (answer == KMessageBox::Cancel)
   {
     return;
@@ -1331,7 +1331,7 @@ void MainWindow::slotNewContinent()
 {
   if (m_onu == nullptr) return;
   qCDebug(KSIRKSKINEDITOR_LOG);
-  QString newContinentName = QInputDialog::getText(this, i18n("New continent name"), i18n("Enter the name of the new continent"));
+  QString newContinentName = QInputDialog::getText(this, i18nc("@title:window", "New Continent Name"), i18nc("@label:textbox", "Enter the name of the new continent:"));
   m_onu->createContinent(newContinentName);
   m_skinDefWidget->continentslist->addItem(newContinentName);
 }
@@ -1341,7 +1341,7 @@ void MainWindow::slotDeleteContinent()
   if (m_onu == nullptr) return;
   if (!m_skinDefWidget->continentslist->currentItem()) return;
   qCDebug(KSIRKSKINEDITOR_LOG);
-  int answer = KMessageBox::warningContinueCancel(this, i18n("Do you really want to delete continent '%1'?", m_skinDefWidget->continentslist->currentItem()->text()), i18n("Really delete continent?"));
+  int answer = KMessageBox::warningContinueCancel(this, i18n("Do you really want to delete continent '%1'?", m_skinDefWidget->continentslist->currentItem()->text()), i18nc("@title:window", "Delete Continent Confirmation"));
   if (answer == KMessageBox::Cancel)
   {
     return;
@@ -1807,24 +1807,20 @@ void MainWindow::slotGoalNbArmiesByCountryChanged(int)
   goal->setNbArmiesByCountry(m_goalDefWidget->armiesbycountry->value());
 }
 
-void MainWindow::slotGoalAnyContinentChanged(int state)
+void MainWindow::slotGoalAnyContinentChanged(bool checked)
 {
   if (m_onu == nullptr || m_skinDefWidget->goalslist->currentItem() == nullptr) return;
   qCDebug(KSIRKSKINEDITOR_LOG);
   int row = m_skinDefWidget->goalslist->row(m_skinDefWidget->goalslist->currentItem());
   Goal* goal = m_onu->goals()[row];
-  switch (state)
-  {
-    case Qt::Unchecked:
+
+  if (!checked) {
       goal->continents().removeAll(QString());
-      break;
-    case Qt::Checked:
+  } else {
       if (!goal->continents().contains(QString()))
       {
         goal->continents().push_back(QString());
       }
-      break;
-    default:;
   }
   goal->setNbArmiesByCountry(m_goalDefWidget->armiesbycountry->value());
 }
@@ -1890,7 +1886,7 @@ void MainWindow::slotDeleteGoal()
   if (m_onu == nullptr) return;
   if (!m_skinDefWidget->goalslist->currentItem()) return;
   qCDebug(KSIRKSKINEDITOR_LOG);
-  int answer = KMessageBox::warningContinueCancel(this, i18n("Do you really want to delete goal '%1'?", m_skinDefWidget->goalslist->currentItem()->text()), i18n("Really delete goal?"));
+  int answer = KMessageBox::warningContinueCancel(this, i18n("Do you really want to delete goal '%1'?", m_skinDefWidget->goalslist->currentItem()->text()), i18nc("@title:window", "Delete Goal Confirmation"));
   if (answer == KMessageBox::Cancel)
   {
     return;
@@ -1949,7 +1945,7 @@ void MainWindow::slotNewNationality()
 {
   if (m_onu == nullptr) return;
   qCDebug(KSIRKSKINEDITOR_LOG);
-  QString newNationalityName = QInputDialog::getText(this, i18n("New nationality name"), i18n("Enter the name of the new nationality"));
+  QString newNationalityName = QInputDialog::getText(this, i18nc("@title:window", "New Nationality Name"), i18nc("@label:textbox", "Enter the name of the new nationality:"));
   m_onu->createNationality(newNationalityName);
   m_skinDefWidget->nationalitieslist->addItem(newNationalityName);
 }
@@ -1959,7 +1955,7 @@ void MainWindow::slotDeleteNationality()
   if (m_onu == nullptr) return;
   if (!m_skinDefWidget->nationalitieslist->currentItem()) return;
   qCDebug(KSIRKSKINEDITOR_LOG);
-  int answer = KMessageBox::warningContinueCancel(this, i18n("Do you really want to delete nationality '%1'?", m_skinDefWidget->nationalitieslist->currentItem()->text()), i18n("Really delete nationality?"));
+  int answer = KMessageBox::warningContinueCancel(this, i18n("Do you really want to delete nationality '%1'?", m_skinDefWidget->nationalitieslist->currentItem()->text()), i18nc("@title:window", "Delete Nationality Confirmation"));
   if (answer == KMessageBox::Cancel)
   {
     return;
